@@ -7,14 +7,12 @@ from collections import Counter
 import re
 
 
-from tqdm import tqdm
 import h5py
 import numpy as np
 from numpy import ndarray
 import pandas as pd
 from scipy.signal import find_peaks
 
-
 import matplotlib.pyplot as plt
 from matplotlib.backends.backend_pdf import PdfPages
 import seaborn as sns
@@ -33,54 +31,30 @@ Main dataframe structure
 # dir = "/home/alan/Documents/dev/skeletons/data/2021_06_15_pypipeline_unit_test_00/2021_06_15_pypipeline_unit_test_00/"
 # dir = "/home/alan/Documents/dev/libs/aliby/data/2021_08_24_2Raf_00/2021_08_24_2Raf_00/"
 dirs = [
-    # # "16543_2019_07_16_aggregates_CTP_switch_2_0glu_0_0glu_URA7young_URA8young_URA8old_01",
-    # # "16545_2019_07_16_aggregates_CTP_switch_2_0glu_0_0glu_URA7young_URA8young_URA8old_secondRun_01",
-    # # "18069_2019_12_05_aggregates_updownshift_2_0_2_URA8_URA7H360A_URA7H360R_00",
-    # # "18616_2020_02_20_protAgg_downUpShift_2_0_2_Ura8_Ura8HA_Ura8HR_01",
-    # # "18617_2020_02_21_protAgg_downUpShift_2_0_2_pHluorin_Ura7HA_Ura7HR_00",
-    # # "19129_2020_09_06_DownUpshift_2_0_2_glu_ura_mig1msn2_phluorin_00",
-    # # "19144_2020_09_07_DownUpshift_2_0_2_glu_ura_mig1msn2_phluorin_secondRound_00",
-    # # "19169_2020_09_09_downUpshift_2_0_2_glu_ura8_phl_mig1_phl_msn2_03",
-    # # "19199_2020_09_29_downUpshift_2_0_2_glu_ura8_ura8h360a_ura8h360r_00",
-    # # "19203_2020_09_30_downUpshift_twice_2_0_2_glu_ura8_ura8h360a_ura8h360r_00",
-    # "19207_2020_10_01_exp_00",
-    # "19232_2020_10_02_downUpshift_twice_2_0_2_glu_ura8_phluorinMsn2_phluorinMig1_01",
-    # "19307_2020_10_22_downUpshift_2_01_2_glucose_dual_pH__dot6_nrg1_tod6__00",
-    # # "19310_2020_10_22_downUpshift_2_0_2_glu_dual_phluorin__glt1_psa1_ura7__thrice_00",
-    # "19311_2020_10_23_downUpshift_2_0_2_glu_dual_phluorin__glt1_psa1_ura7__twice__04",
-    # # "19328_2020_10_31_downUpshift_four_2_0_2_glu_dual_phl__glt1_ura8_ura8__00",
-    # # "19329_2020_11_01_exp_00",
-    # # "19333_2020_11_02_downUpshift_2_0_2_glu_ura7_ura7ha_ura7hr_00",
-    # # "19334_2020_11_02_downUpshift_2_0_2_glu_ura8_ura8ha_ura8hr_00",
-    # "19447_2020_11_18_downUpshift_2_0_2_glu_gcd2_gcd6_gcd7__02",
-    # # "19810_2021_02_21_ToxicityTest_00",
-    # # "19993_2021_06_15_pypipeline_unit_test_00",
-    # # "19996_2021_06_27_ph_calibration_dual_phl_ura8_5_04_5_83_7_69_7_13_6_59__01",
-    # # "20419_2021_11_02_dose_response_raf_05_075_2_glu_005_2_constantMedia_00",
-    # "16543_2019_07_16_aggregates_CTP_switch_2_0glu_0_0glu_URA7young_URA8young_URA8old_01",
-    # "16545_2019_07_16_aggregates_CTP_switch_2_0glu_0_0glu_URA7young_URA8young_URA8old_secondRun_01",
-    # "18069_2019_12_05_aggregates_updownshift_2_0_2_URA8_URA7H360A_URA7H360R_00",
-    # "18616_2020_02_20_protAgg_downUpShift_2_0_2_Ura8_Ura8HA_Ura8HR_01",
-    # "18617_2020_02_21_protAgg_downUpShift_2_0_2_pHluorin_Ura7HA_Ura7HR_00",
+    "16543_2019_07_16_aggregates_CTP_switch_2_0glu_0_0glu_URA7young_URA8young_URA8old_01",
+    "16545_2019_07_16_aggregates_CTP_switch_2_0glu_0_0glu_URA7young_URA8young_URA8old_secondRun_01",
+    "18069_2019_12_05_aggregates_updownshift_2_0_2_URA8_URA7H360A_URA7H360R_00",
+    "18616_2020_02_20_protAgg_downUpShift_2_0_2_Ura8_Ura8HA_Ura8HR_01",
+    "18617_2020_02_21_protAgg_downUpShift_2_0_2_pHluorin_Ura7HA_Ura7HR_00",
     "19129_2020_09_06_DownUpshift_2_0_2_glu_ura_mig1msn2_phluorin_00",
-    # "19144_2020_09_07_DownUpshift_2_0_2_glu_ura_mig1msn2_phluorin_secondRound_00",
-    # "19169_2020_09_09_downUpshift_2_0_2_glu_ura8_phl_mig1_phl_msn2_03",
-    # "19199_2020_09_29_downUpshift_2_0_2_glu_ura8_ura8h360a_ura8h360r_00",
-    # "19203_2020_09_30_downUpshift_twice_2_0_2_glu_ura8_ura8h360a_ura8h360r_00",
-    # "19207_2020_10_01_exp_00",
-    # "19232_2020_10_02_downUpshift_twice_2_0_2_glu_ura8_phluorinMsn2_phluorinMig1_01",
-    # "19307_2020_10_22_downUpshift_2_01_2_glucose_dual_pH__dot6_nrg1_tod6__00",
-    # "19310_2020_10_22_downUpshift_2_0_2_glu_dual_phluorin__glt1_psa1_ura7__thrice_00",
-    # "19311_2020_10_23_downUpshift_2_0_2_glu_dual_phluorin__glt1_psa1_ura7__twice__04",
-    # "19328_2020_10_31_downUpshift_four_2_0_2_glu_dual_phl__glt1_ura8_ura8__00",
-    # "19329_2020_11_01_exp_00",
-    # "19333_2020_11_02_downUpshift_2_0_2_glu_ura7_ura7ha_ura7hr_00",
-    # "19334_2020_11_02_downUpshift_2_0_2_glu_ura8_ura8ha_ura8hr_00",
-    # "19447_2020_11_18_downUpshift_2_0_2_glu_gcd2_gcd6_gcd7__02",
-    # "19810_2021_02_21_ToxicityTest_00",
-    # "19993_2021_06_15_pypipeline_unit_test_00",
-    # "19996_2021_06_27_ph_calibration_dual_phl_ura8_5_04_5_83_7_69_7_13_6_59__01",
-    # "20419_2021_11_02_dose_response_raf_05_075_2_glu_005_2_constantMedia_00",
+    "19144_2020_09_07_DownUpshift_2_0_2_glu_ura_mig1msn2_phluorin_secondRound_00",
+    "19169_2020_09_09_downUpshift_2_0_2_glu_ura8_phl_mig1_phl_msn2_03",
+    "19199_2020_09_29_downUpshift_2_0_2_glu_ura8_ura8h360a_ura8h360r_00",
+    "19203_2020_09_30_downUpshift_twice_2_0_2_glu_ura8_ura8h360a_ura8h360r_00",
+    "19207_2020_10_01_exp_00",
+    "19232_2020_10_02_downUpshift_twice_2_0_2_glu_ura8_phluorinMsn2_phluorinMig1_01",
+    "19307_2020_10_22_downUpshift_2_01_2_glucose_dual_pH__dot6_nrg1_tod6__00",
+    "19310_2020_10_22_downUpshift_2_0_2_glu_dual_phluorin__glt1_psa1_ura7__thrice_00",
+    "19311_2020_10_23_downUpshift_2_0_2_glu_dual_phluorin__glt1_psa1_ura7__twice__04",
+    "19328_2020_10_31_downUpshift_four_2_0_2_glu_dual_phl__glt1_ura8_ura8__00",
+    "19329_2020_11_01_exp_00",
+    "19333_2020_11_02_downUpshift_2_0_2_glu_ura7_ura7ha_ura7hr_00",
+    "19334_2020_11_02_downUpshift_2_0_2_glu_ura8_ura8ha_ura8hr_00",
+    "19447_2020_11_18_downUpshift_2_0_2_glu_gcd2_gcd6_gcd7__02",
+    "19810_2021_02_21_ToxicityTest_00",
+    "19993_2021_06_15_pypipeline_unit_test_00",
+    "19996_2021_06_27_ph_calibration_dual_phl_ura8_5_04_5_83_7_69_7_13_6_59__01",
+    "20419_2021_11_02_dose_response_raf_05_075_2_glu_005_2_constantMedia_00",
 ]
 # outdir = "/home/alan/Documents/dev/skeletons/data"
 # dirs = Path(outdir).glob("*ph*")
@@ -224,7 +198,7 @@ class ExperimentCompiler(Compiler):
         }
 
         input_signals = {
-            k: self.grouper.concat_signal(v, pool=0) for k, v in names_signals.items()
+            k: self.grouper.concat_signal(v) for k, v in names_signals.items()
         }
 
         ids = input_signals["births"].index
@@ -244,7 +218,7 @@ class ExperimentCompiler(Compiler):
                 )
 
             stages_dfs = {
-                "Full": process_dfs(input_signals, range(compiler.meta.ntimepoints))
+                "Full": process_dfs(input_signals, range(compiler.grouper.ntimepoints))
             }
             for k, rng in stages:
                 stage_df = process_dfs(input_signals, rng)
@@ -288,12 +262,14 @@ class ExperimentCompiler(Compiler):
 
             intervals = np.array((0, *switch_times, last_tp), dtype=int)
 
-            stages = [
+            extracted_tps = self.grouper.ntimepoints
+            stages = [  # Only add intervals with length larger than zero
                 (
                     ": ".join((str(i + 1), pump_contents[p_id])),
-                    range(intervals[i], intervals[i + 1]),
+                    range(intervals[i], min(intervals[i + 1], extracted_tps)),
                 )
                 for i, p_id in enumerate(main_pump)
+                if (intervals[i + 1] > intervals[i])
             ]
             return stages
 
@@ -325,7 +301,7 @@ class ExperimentCompiler(Compiler):
         }
 
         input_signals = {
-            k: self.grouper.concat_signal(v) for k, v in tqdm(names_signals.items())
+            k: self.grouper.concat_signal(v) for k, v in names_signals.items()
         }
         ids = self.get_shared_ids(input_signals, min_nbirths=min_nbirths)
 
@@ -375,7 +351,7 @@ class ExperimentCompiler(Compiler):
 
     def compile_slices(self, nslices=2, *args, **kwargs):
         tps = [
-            min(i * (self.meta.ntimepoints // nslices), self.meta.ntimepoints - 1)
+            min(i * (self.grouper.ntimepoints // nslices), self.grouper.ntimepoints - 1)
             for i in range(nslices + 1)
         ]
         slices = [self.compile_slice(tp=tp) for tp in tps]
@@ -643,9 +619,9 @@ class Reporter(object):
 
         if pages is None:
             pages = {
-                "fluorescence": self.gen_page_fluorescence(),
-                "growth": self.gen_page_growth(),
                 "qa": self.gen_page_qa(),
+                "growth": self.gen_page_growth(),
+                "fluorescence": self.gen_page_fluorescence(),
             }
         self.pages = pages
 
@@ -767,8 +743,8 @@ class Reporter(object):
         )
 
     def gen_all_instructions(self):
-        growth = self.gen_page_growth()
         qa = self.gen_page_qa()
+        growth = self.gen_page_growth()
 
         return (qa, growth)
 
@@ -818,26 +794,12 @@ class PageOrganiser(object):
             yloc = 0
 
         if self.single_fig:  # If plotting using a figure method using seaborn cols/rows
-            # plt.rcParams["axes.labelsize"] = 15
-            # plt.rcParams["axes.titlesize"] = 15
-            # plt.rcParams["xtick.labelsize"] = 15
-            # plt.rcParams["ytick.labelsize"] = 15
-            # plt.rcParams["legend.fontsize"] = 15
-            # plt.rcParams["figure.figsize"] = (8.27, 11.69)
-            # plt.rcParams["figure.figsize"] = (11.69, 8.27)
-            # sns.set(rc={"figure.figsize": (11.7, 8.27)})
             self.g = func(*args, **kwargs)
             self.axes = {
                 ax.title.get_text().split("=")[-1][1:]: ax for ax in self.g.axes.flat
             }
             self.fig = self.g.fig
-
-            # plt.rcParams["axes.labelsize"] = 15
-            # plt.rcParams["axes.titlesize"] = 15
-            # plt.rcParams["xtick.labelsize"] = 15
-            # plt.rcParams["ytick.labelsize"] = 15
         else:
-            plt.rcParams["legend.fontsize"] = 5
             self.axes[(xloc, yloc)] = self.fig.add_subplot(self.gs[xloc, yloc])
             func(
                 *args,
@@ -900,17 +862,6 @@ class PageOrganiser(object):
 
 # base_dir = Path("/home/alan/Documents/dev/skeletons/scripts/data/")
 # for dir in dirs:
-#     # try:
-#     compiler = ExperimentCompiler(None, base_dir / dir)
-#     dfs = compiler.run()
-#     rep = Reporter(data=dfs, path=base_dir / (dir + "/report.pdf"))
-
-#     rep.plot_report(base_dir / (dir + "/report.pdf"))
-# except Exception as e:
-#     print(f"LOG:ERROR:{dir}: {e}")
-
-
-# def try_report(dir, base_dir=base_dir):
 #     try:
 #         compiler = ExperimentCompiler(None, base_dir / dir)
 #         dfs = compiler.run()
@@ -920,15 +871,5 @@ class PageOrganiser(object):
 #         rep.plot_report(base_dir / (dir + "/report.pdf"))
 #     except Exception as e:
 #         print("LOG:ERROR:", e)
-#         return e
-
-
-# from p_tqdm import p_map
-
-# results = p_map(
-#     lambda x: try_report(dir=x),
-#     dirs,
-# )
-
-# # with open("errors.log", "a") as f:
-# #     f.write(e)
+# with open("errors.log", "a") as f:
+#     f.write(e)
