@@ -6,7 +6,8 @@ import pandas as pd
 from sklearn import decomposition
 from catch22 import catch22_all
 
-from agora.abc import ParametersABC, ProcessABC
+from agora.abc import ParametersABC
+from postprocessor.core.abc import PostProcessABC
 
 
 class catch22Parameters(ParametersABC):
@@ -15,21 +16,13 @@ class catch22Parameters(ParametersABC):
         :min_len: Prefilter to account only for long-signal cells
     """
 
-    def __init__(self, min_len, n_components):
-        self.min_len = min_len
-        self.n_components = n_components
-
-    @classmethod
-    def default(cls):
-        return cls.from_dict(
-            {
-                "min_len": 0.8,
-                "n_components": None,
-            }
-        )
+    _defaults = {
+        "min_len": 0.8,
+        "n_components": None,
+    }
 
 
-class catch22(ProcessABC):
+class catch22(PostProcessABC):
     """
     catch22 class. It produces 22 normalised features for each time lapse in the signal (using the catch22 library.)
     """
