@@ -1,6 +1,7 @@
 import pandas as pd
 
-from agora.abc import ParametersABC, ProcessABC
+from agora.abc import ParametersABC
+from postprocessor.core.abc import PostProcessABC
 
 
 class dsignalParameters(ParametersABC):
@@ -8,15 +9,10 @@ class dsignalParameters(ParametersABC):
     :window: Number of timepoints to consider for signal.
     """
 
-    def __init__(self, window: int):
-        self.window = window
-
-    @classmethod
-    def default(cls):
-        return cls.from_dict({"window": 3})
+    _defaults = {"window": 3}
 
 
-class dsignal(ProcessABC):
+class dsignal(PostProcessABC):
     """
     Calculate the change in a signal depending on a window
     """
