@@ -1,10 +1,12 @@
 """Gaussian process fit of a Signal."""
 import logging
 
-from postprocessor.core.processes.base import ParametersABC, ProcessABC
+
 import numpy as np
 import pandas as pd
 
+from agora.abc import ParametersABC
+from postprocessor.core.abc import PostProcessABC
 import gaussianprocessderivatives as gp
 
 
@@ -63,34 +65,25 @@ def estimate_gr(volume, dt, noruns, bounds, verbose):
 
 
 class gpsignalParameters(ParametersABC):
-    default_dict = dict(
+    """
+    Parameters
+    ----------
+        dt : float
+            The time step between time points, in minutes
+        noruns : int
+            The number of times the optimisation is tried
+        bounds : dict
+            Hyperparameter bounds for the Matern Kernel
+        verbose : bool
+            Determines whether to print hyperparameter results
+    """
+
+    _defaults = dict(
         dt=5, noruns=5, bounds={0: (-2, 3), 1: (-2, 1), 2: (-4, -1)}, verbose=False
     )
 
-    def __init__(self, dt, noruns, bounds, verbose):
-        """
-        Parameters
-        ----------
-            dt : float
-                The time step between time points, in minutes
-            noruns : int
-                The number of times the optimisation is tried
-            bounds : dict
-                Hyperparameter bounds for the Matern Kernel
-            verbose : bool
-                Determines whether to print hyperparameter results
-        """
-        self.dt = dt
-        self.noruns = noruns
-        self.bounds = bounds
-        self.verbose = verbose
 
-    @classmethod
-    def default(cls):
-        return cls.from_dict(cls.default_dict)
-
-
-class gpsignal(ProcessABC):
+class gpsignal(PostProcessABC):
     """Gaussian process fit of a Signal."""
 
     def __init__(self, parameters: gpsignalParameters):
