@@ -6,7 +6,8 @@ from itertools import product
 import igraph as ig
 import leidenalg
 
-from agora.abc import ParametersABC, ProcessABC
+from agora.abc import ParametersABC
+from postprocessor.core.abc import PostProcessABC
 
 
 class leidenParameters(ParametersABC):
@@ -14,17 +15,10 @@ class leidenParameters(ParametersABC):
     Parameters
     """
 
-    def __init__(
-        self,
-    ):
-        super().__init__()
-
-    @classmethod
-    def default(cls):
-        return cls.from_dict({})
+    _defaults = {}
 
 
-class leiden(ProcessABC):
+class leiden(PostProcessABC):
     """
     leiden algorithm applied to a dataframe with features.
     """
