@@ -1,7 +1,8 @@
 import numpy as np
 import pandas as pd
 
-from agora.abc import ParametersABC, ProcessABC
+from agora.abc import ParametersABC
+from postprocessor.core.abc import PostProcessABC
 
 
 class LineageProcessParameters(ParametersABC):
@@ -9,17 +10,10 @@ class LineageProcessParameters(ParametersABC):
     Parameters
     """
 
-    def __init__(
-        self,
-    ):
-        super().__init__()
-
-    @classmethod
-    def default(cls):
-        return cls.from_dict({})
+    _defaults = {}
 
 
-class LineageProcess(ProcessABC):
+class LineageProcess(PostProcessABC):
     """
     Lineage process that must be passed a (N,3) lineage matrix (where the coliumns are trap, mother, daughter respectively)
     """
