@@ -3,7 +3,8 @@
 
 import pandas as pd
 
-from agora.abc import ParametersABC, ProcessABC
+from agora.abc import ParametersABC
+from postprocessor.core.abc import PostProcessABC
 
 
 class signalParameters(ParametersABC):
@@ -11,15 +12,10 @@ class signalParameters(ParametersABC):
     :window: Number of timepoints to consider for signal.
     """
 
-    def __init__(self, window: int):
-        self.window = window
-
-    @classmethod
-    def default(cls):
-        return cls.from_dict({"window": 3})
+    _defaults = {"window": 3}
 
 
-class mednorm(ProcessABC):
+class mednorm(PostProcessABC):
     """
     Normalise a channel by the median
     """
