@@ -1,5 +1,7 @@
 from scipy.signal import argrelmax, argrelmin
-from postprocessor.core.processes.base import ParametersABC, ProcessABC
+
+from agora.abc import ParametersABC
+from postprocessor.core.abc import PostProcessABC
 
 
 class PeaksParameters(ParametersABC):
@@ -10,15 +12,10 @@ class PeaksParameters(ParametersABC):
             how many points to use for comparison.
     """
 
-    def __init__(self, type):
-        self.type = type
-
-    @classmethod
-    def default(cls):
-        return cls.from_dict({"type": "minima", "order": 3})
+    _defaults = {"type": "minima", "order": 3}
 
 
-class Peaks(ProcessABC):
+class Peaks(PostProcessABC):
     """
     Identifies a signal sharply dropping.
     """
