@@ -2,7 +2,8 @@ import numpy as np
 import pandas as pd
 from scipy.signal import savgol_filter
 
-from postprocessor.core.processes.base import ParametersABC, ProcessABC
+from agora.abc import ParametersABC
+from postprocessor.core.abc import PostProcessABC
 
 
 class savgolParameters(ParametersABC):
@@ -15,16 +16,10 @@ class savgolParameters(ParametersABC):
             The order of polynom used. Must be smaller than the window size
     """
 
-    def __init__(self, window, polynom):
-        self.window = window
-        self.polynom = polynom
-
-    @classmethod
-    def default(cls):
-        return cls.from_dict({"window": 7, "polynom": 3})
+    _defaults = {"window": 7, "polynom": 3}
 
 
-class savgol(ProcessABC):
+class savgol(PostProcessABC):
     """
     Apply Savitzky-Golay filter (works with NaNs, but it might return
     NaN regions).
