@@ -1,7 +1,8 @@
 import numpy as np
 import pandas as pd
 
-from agora.abc import ParametersABC, ProcessABC
+from agora.abc import ParametersABC
+from postprocessor.core.abc import PostProcessABC
 
 
 class TemplateParameters(ParametersABC):
@@ -9,17 +10,10 @@ class TemplateParameters(ParametersABC):
     Parameters
     """
 
-    def __init__(
-        self,
-    ):
-        super().__init__()
-
-    @classmethod
-    def default(cls):
-        return cls.from_dict({})
+    _defaults = {}
 
 
-class Template(ProcessABC):
+class Template(PostProcessABC):
     """
     Template for process class.
     """
