@@ -7,11 +7,12 @@ import pandas as pd
 
 from tqdm import tqdm
 
-from agora.abc import ParametersABC
+from agora.abc import ParametersABC, ProcessABC
 from agora.io.writer import Writer
 from agora.io.signal import Signal
-from agora.io.cells import Cells
+from agora.io.cells import CellsLinear as Cells
 
+from postprocessor.core.abc import get_process, get_parameters
 from postprocessor.core.processes.merger import mergerParameters, merger
 from postprocessor.core.processes.picker import pickerParameters, picker
 from postprocessor.core.processes.lineageprocess import LineageProcessParameters
@@ -31,11 +32,11 @@ class PostProcessorParameters(ParametersABC):
     def __init__(
         self,
         targets={},
-        parameters={},
+        param_sets={},
         outpaths={},
     ):
         self.targets: Dict = targets
-        self.parameters: Dict = parameters
+        self.param_sets: Dict = param_sets
         self.outpaths: Dict = outpaths
 
     def __getitem__(self, item):
@@ -105,7 +106,7 @@ class PostProcessorParameters(ParametersABC):
                 ],
             ],
         }
-        parameters = {
+        param_sets = {
             "prepost": {
                 "merger": mergerParameters.default(),
                 "picker": pickerParameters.default(),
@@ -150,54 +151,35 @@ class PostProcessorParameters(ParametersABC):
                 ],
             )
 
-        return cls(targets=targets, parameters=parameters, outpaths=outpaths)
+        return cls(targets=targets, param_sets=param_sets, outpaths=outpaths)
 
 
-class PostProcessor:
+class PostProcessor(ProcessABC):
     def __init__(self, filename, parameters):
-        self.parameters = parameters
+        super().__init__(parameters)
         self._filename = filename
         self._signal = Signal(filename)
         self._writer = Writer(filename)
 
         # self.outpaths = parameters["outpaths"]
         self.merger = merger(
-            mergerParameters.from_dict(parameters["parameters"]["prepost"]["merger"])
+            mergerParameters.from_dict(parameters["param_sets"]["prepost"]["merger"])
         )
 
         self.picker = picker(
-            pickerParameters.from_dict(parameters["parameters"]["prepost"]["picker"]),
+            pickerParameters.from_dict(parameters["param_sets"]["prepost"]["picker"]),
             cells=Cells.from_source(filename),
         )
         self.classfun = {
-            process: self.get_process(process)
+            process: get_process(process)
             for process, _ in parameters["targets"]["processes"]
         }
         self.parameters_classfun = {
-            process: self.get_parameters(process)
+            process: get_parameters(process)
             for process, _ in parameters["targets"]["processes"]
         }
         self.targets = parameters["targets"]
 
-    def get_parameters(self, process):
-        """
-        Dynamically import parameters from the 'processes' folder.
-        Assumes parameter is the same name as the file with 'Parameters' added at the end.
-        """
-        return self.get_process(process, suffix="Parameters")
-
-    @staticmethod
-    def get_process(process, suffix=""):
-        """
-        Dynamically import a process class from the 'processes' folder.
-        Assumes process filename and class name are the same
-        """
-        location = f"postprocessor.core.processes.{process}.{process}{suffix}"
-        found = locate(location)
-        if found == None:
-            raise Exception(f"{location} not found")
-        return found
-
     def run_prepost(self):
         """Important processes run before normal post-processing ones"""
 
@@ -311,7 +293,7 @@ class PostProcessor:
         self.run_prepost()
 
         for process, datasets in tqdm(self.targets["processes"]):
-            if process in self.parameters["parameters"].get(
+            if process in self.parameters["param_sets"].get(
                 "processes", {}
             ):  # If we assigned parameters
                 parameters = self.parameters_classfun[process](self.parameters[process])
